@@ -1,6 +1,6 @@
 name = "pycromanager"
 
-from pycromanager.acquire import Acquisition, multi_d_acquisition_events
+from pycromanager.acquire import Acquisition, multi_d_acquisition_events, start_headless
 from pycromanager.core import Bridge, JavaObjectShadow
 from pycromanager.data import Dataset
 from ._version import __version__, version_info
